pub struct BridgeConfig {
pub bridge_width: f64,
pub max_spacing: f64,
pub min_bridges: usize,
pub corner_clearance: f64,
pub enabled: bool,
}Expand description
Configuration for bridge/tab placement.
Fields
bridge_width: f64Width of each bridge (uncut segment length) in mm.
max_spacing: f64Maximum spacing between bridges along the perimeter. More bridges are added if the spacing exceeds this value.
min_bridges: usizeMinimum number of bridges per contour.
corner_clearance: f64Minimum clearance from vertices (corners) in mm. Bridges won’t be placed within this distance of a vertex.
enabled: boolWhether bridge placement is enabled.